# SpinSpotter
SpinSpotter is an automated algorithm to calculate stellar rotation periods from high-cadence photometry.
SpinSpotter is currently still under construction! The code hosted here functions but is still being cleaned up for usability.

## Hey you! (Yes you :D)
Thanks for checking out SpinSpotter! Please be aware that the code is in beta and things are changing fast--new tutorials, installation options, testing suites, and code functionality are being added as we speak. I highly recommend checking back pulling new updates often to make sure you're always working with the most up-to-date version of the code. And if you run into any issues or want to request certain features, please reach out to me!

## Installation
Please install SpinSpotter using

`pip install git+https://github.com/rae-holcomb/SpinSpotter`

More installation options will be added soon.


## Tutorials
For an introduction to using SpinSpotter, check out the jupyter notebook tutorial in [github_tutorial.ipynb](./github_tutorial.ipynb).

More tutorials to be added soon!

![This is an image](/./images/acf_param_plot.png)

## Documentation
Documentation for SpinSpotter can be found here: [https://raeholcomb-spinspotter.readthedocs.io/en/latest/](https://raeholcomb-spinspotter.readthedocs.io/en/latest/)
